let data;
let svg;

let canvasWidth = 800;
let canvasHeight = 500;
let margin = 150;
let w = canvasWidth - margin;
let h = canvasHeight - margin;

const xLabel = "Year";
const yLabel = "Share of production (%)";

const fetchCSV = async() => {
    //fetch csv data
    const pathToCSV = "https://gist.githubusercontent.com/colmpat/e12ac84c36022d5b22f95c9df9af3297/raw/8f5c1a9c0967ac36192a02332459a5ec8e073a84/Europe-Power-Sector-Processed.csv";
    
    data = await d3.csv(pathToCSV, d => {
        return {
            year: parseInt(d[xLabel]),
            share: parseInt(d[yLabel])
        };
    });
    
}

const drawBars = async() => {

    //load in csv
    try {
        await fetchCSV();
    } catch (e) {
        console.log("there was an error loading the csv file:\n", e);
    }



    svg = d3.select("body").append("svg")
        .attr("width",  canvasWidth)
        .attr("height", canvasHeight);

    //------Title-----------
    svg.append("text")
        .attr("text-anchor", "middle")
        .attr("x", canvasWidth / 2)
        .attr("y", 30)
        .text("Avg. Share of Production for Renewables (EU Member States)");




    //------axis scales-------------
    let xScale = d3.scaleBand()
        .domain(data.map(d => d.year))
        .range([0, w]);
        
    
    let yScale = d3.scaleLinear()
        .domain([0, d3.max(data.map(d => d.share))])
        .range([h, 0]);
    




    //prepare main container group
    let container_g = svg.append("g")
        .attr("transform", `translate(${margin / 2}, ${margin / 2})`);

    // Display the X-axis
    container_g.append("g")
        .attr("transform", `translate(0, ${h})`)
        .call(d3.axisBottom(xScale).tickFormat(d => {
            if(d % 5 === 0){
                return d;
            }
        }).tickSizeOuter(0))
        .append("text")

    //label x
    svg.append("text")
        .attr("class", "x label")
        .attr("text-anchor", "middle")
        .attr("x", canvasWidth / 2)
        .attr("y", canvasHeight - 15)
        .text(xLabel)
    

    // Display the Y-axis
    container_g.append("g")
    .call(d3.axisLeft(yScale).tickFormat(d => d + "%"));

    //label y
    svg.append("text")
        .attr("class", "y label")
        .attr("transform", "rotate(-90)")
        .attr("text-anchor", "middle")
        .attr("x", canvasHeight / -2)
        .attr("y", 22)
        .text(yLabel)


    //prepare wrapper groups:
    let groups = container_g.selectAll(null)
        .data(data)
        .enter()
        .append("g")
        .attr("class", "bar-wrapper");

    //add bars to the groups
    groups.append("rect")
        .attr("class", "bar rect")
        .attr("x", d => xScale(d.year) + 2)
        .attr("y", d => h - yScale(0) + yScale(d.share))
        .attr("width", w / data.length - 2)
        .attr("height", d => yScale(0) - yScale(d.share));

    //add text for hover interaction to the groups
    groups.append("text")
        .attr("class", "bar label")
        .attr("text-anchor", "left")
        .attr("x", d => xScale(d.year) + 4)
        .attr("y", d => h - yScale(0) + yScale(d.share) + 15)
        .text(d => d.share + "%");

}

drawBars();
